@@ -19,6 +19,8 @@ from unforward.emailclients.emailclient import EmailClient
 from unforward.errors import ExtractionError
 from bs4 import BeautifulSoup
 from pprint import pprint
+import datetime
+
 
 class GmailClient(EmailClient):
     """ Extracts originals from gmail clients."""
@@ -42,14 +44,17 @@ class GmailClient(EmailClient):
                 gmail_quote = parsed.div.find("div", class_ = "gmail_quote")
                 if gmail_quote.div is None:
                     body = ''.join(str(tag).strip() for tag in gmail_quote.contents[18:])
+                    date = datetime.datetime.strptime(gmail_quote.contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
                     sender = gmail_quote.span.a.get_text()
                 elif len(gmail_quote) < 10:
                     body = ''.join(str(tag).strip() for tag in gmail_quote.contents[1:])
+                    date = None
                     sender = gmail_quote.span.a.get_text()                
                 else:
                     body = ''.join(str(tag).strip() for tag in gmail_quote.div.contents)
+                    date = datetime.datetime.strptime(gmail_quote.contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
                     sender = gmail_quote.span.a.get_text()
-                return {"body" : body, "sender" : sender}
+                return {"body" : body, "sender" : sender, "date" : date}
             else:
                 raise ExtractionError("Parsing of forward failed.")
                 
