@@ -15,54 +15,64 @@
 #
 #
 
+import datetime
+
 examples =  [
                 {
                     "client": ["outlook", "iphone"], # Outlook and iphone forward in exactly the same way
                     "file" : "examples/outlook_express_forward.html",
                     "result" : {'sender' : 'laolaw@lao.on.ca',
-                                'body'   : '<p>Original Email</p>'}
+                                'body'   : '<p>Original Email</p>',
+                                'date'   : datetime.datetime(2014, 4, 17, 15, 39, 52)}
                 },
                 {
                     "client": ["gmail"],
                     "file" : "examples/gmail_forward_1.html",
                     "result" : {'sender' : 'jamie@moonrider.com',
-                                'body'   : '<p> Original Email</p>'}
+                                'body'   : '<p> Original Email</p>',
+                                'date'   : datetime.datetime(2014, 4, 16, 17, 9, 0)}
                 },
                 {
                     "client": ["gmail"],
                     "file" : "examples/gmail_forward_3.html",
                     "result" : {'sender' : 'builds@drone.io',
-                                'body'   : '<br/><p>Build Failed</p>'}
+                                'body'   : '<br/><p>Build Failed</p>',
+                                'date'   : datetime.datetime(2014, 4, 21, 14, 35, 0)}
                 },
                 {
                     "client": ["gmail"],
                     "file" : "examples/gmail_forward_5.html",
                     "result" : {'sender' : 'customercare_canada@homedepot.com',
-                                'body'   : '<p>TEST</p>'}
+                                'body'   : '<p>TEST</p>',
+                                'date'   : datetime.datetime(2013, 8, 21, 21, 53, 0)}
                 },
                 {
                     "client": ["blackberry"],
                     "file" : "examples/blackberry_forward.html",
                     "result" : {'sender' : 'efenkell@gmail.com',
-                                'body'   : '<p>Original Email</p>'}
+                                'body'   : '<p>Original Email</p>',
+                                'date'   : None}
                 },
                 {
                     "client": ["iphone", "outlook"], # Outlook and iphone forward in exactly the same way
                     "file" : "examples/iphone_forward.html",
                     "result" : {'sender' : 'dmz@ryerson.ca',
-                                'body'   : '<p>Original Email</p>'}
+                                'body'   : '<p>Original Email</p>',
+                                'date'   : datetime.datetime(2014, 4, 17, 12, 50, 56)}
                 },
                 {
                     "client": ["lotusnotes"],
                     "file" : "examples/lotus_notes_forward.txt",
                     "result" : {'sender' : 'jamie@getsensibill.com',
-                                'body'   : 'Original Email'}
+                                'body'   : 'Original Email',
+                                'date'   : None}
                 },
                 {
                     "client": ["yahoo"],
                     "file" : "examples/yahoo_forward.html",
                     "result" : {'sender' : 'noreply@3scale.net',
-                                'body'   : '<p> Original Email</p>'}
+                                'body'   : '<p> Original Email</p>',
+                                'date'   : None}
                 }
             ]
 
